@@ -34,7 +34,7 @@ def get_section_beg_end(tg, req_section):
                          '':['ͶĿ','ͶʷΧ','Ͷ','׾Լ¶','ȫݶڴȨͬ','Ԥֹ','˽ļзشʩ','𱸰ǰֽ','ȯ','Ͷʾ'],
                          '':['ͶĿ','ͶʷΧ','Ͷʲ','Ͷ','Ͷʾָ','ҵȽϻ׼','տ','ڴ͸ԭԼ','ͶʽֹΪ','ʹƲͶ֤ȯȨԭ򼰷','',''],
                          '':['ͶĿ','ͶʷΧ','Ͷʲ','Ͷ','ͶʽֹΪ','Ͷʾָͱ','տ','׼ͻ',''],
-                         '':['Ͷʾ','ͶĿ','ͶʷΧ','Ͷʲ','Ͷ','ͶʽֹΪ','׼ͻμʽ','','Ԥֹ','ҵȽϻ׼','йͶʼලԼ'],
+                         '':['ͶĿ','ͶʷΧ','ͶʷΧı','Ͷʲ','Ͷ','ֹΪ','ͻ','ȫݶڴȨͬ⣺','Ԥƽֻ','ʡȯ֤ȯҵ','йͶʼලΧ'],
                          '㷢':['Ʋı봦','Ʋ˻Ŀ͹', 'ͶʷΧ','Ͷʲ','Ͷ','ͶʽֹΪ','׼ͻμʽ','','Ԥֹ','ҵȽϻ׼','йͶʼලԼ'],
                          'ͨ':['Ͷʾ','ͶĿ','ͶʷΧ','Ͷʲ','Ͷ','ͶʽֹΪ','׵μʽ','','ҵȽϻ׼','ȯҵ֤ȯҵ','Ԥֹ'],
                          'ƽ':['ͶĿ','ͶʷΧ','Ͷʲ','Ͷ','/','ͶʽֹΪ','Ԥֹտ','ҵȽϻ׼У','','Ͷߵı'],
@@ -367,36 +367,36 @@ def get_chapter_beg_end(tg, req_chapter):
                                 'úĴ',\
                                 ''],
 
-                        'Ͷ':['Ҫʾ?',\
-                                'ŻƱ8˽ļ֤ȯͶʻսʾ?',\
-                                'ϸͶ߳ŵ?',\
-                                'Ͷ߸֪?',\
-                                'һǰ?',\
-                                '?',\
-                                'ŵ?',\
-                                'ġ˽ļĻ?',\
-                                '塢˽ļĽṹ?',\
-                                '˽ļļ?',\
-                                'ߡ˽ļĳ뱸?',\
-                                'ˡ˽ļ깺غת?',\
-                                'š˵Ȩ?',\
-                                'ʮݶ˴ἰճ?',\
-                                'ʮһ˽ļݶĵǼ?',\
-                                'ʮ˽ļͶ?',\
-                                'ʮ˽ļĲƲ?',\
-                                'ʮġʽ㽻հ?',\
-                                'ʮ塢Ͷָķ͡ȷϺִ?',\
-                                'ʮ˽ļʲĹֵͻƺ?',\
-                                'ʮߡ˽ļķ˰?',\
-                                'ʮˡ˽ļ?',\
-                                'ʮšϢ¶뱨?',\
-                                'ʮսʾ?',\
-                                'ʮһ˽ļͬЧֹ?',\
-                                'ʮ˽ļ?',\
-                                'ʮΥԼ?',\
-                                'ʮġĴ?',\
-                                'ʮ塢ά?',\
-                                'ʮ?'],
+                        'Ͷ':['Ҫʾ',\
+                                'ŻƱ8˽ļ֤ȯͶʻսʾ',\
+                                'ϸͶ߳ŵ',\
+                                'Ͷ߸֪',\
+                                'һǰ',\
+                                '',\
+                                'ŵ',\
+                                'ġ˽ļĻ',\
+                                '塢˽ļĽṹ',\
+                                '˽ļļ',\
+                                'ߡ˽ļĳ뱸',\
+                                'ˡ˽ļ깺غת',\
+                                'š˵Ȩ',\
+                                'ʮݶ˴ἰճ',\
+                                'ʮһ˽ļݶĵǼ',\
+                                'ʮ˽ļͶ',\
+                                'ʮ˽ļĲƲ',\
+                                'ʮġʽ㽻հ',\
+                                'ʮ塢Ͷָķ͡ȷϺִ',\
+                                'ʮ˽ļʲĹֵͻƺ',\
+                                'ʮߡ˽ļķ˰',\
+                                'ʮˡ˽ļ',\
+                                'ʮšϢ¶뱨',\
+                                'ʮսʾ',\
+                                'ʮһ˽ļͬЧֹ',\
+                                'ʮ˽ļ',\
+                                'ʮΥԼ',\
+                                'ʮġĴ',\
+                                'ʮ塢ά',\
+                                'ʮ'],
                         
                         '':['һǰ',\
                                 '',\
